@@ -16,6 +16,7 @@ import {
 import { setupExplore, waitForExplore } from 'app/features/explore/spec/helper/setup';
 
 import { silenceConsoleOutput } from '../../../test/core/utils/silenceConsoleOutput';
+import { contextSrv } from '../../core/services/context_srv';
 import { addExtraMiddleware, addRootReducer } from '../../store/configureStore';
 
 import { QueryLibraryContextProvider } from './QueryLibraryContextProvider';
@@ -62,7 +63,7 @@ jest.mock('@grafana/runtime', () => ({
   usePluginLinks: jest.fn().mockReturnValue({ links: [] }),
 }));
 
-jest.mock('app/core/core', () => ({
+jest.mock('app/core/services/context_srv', () => ({
   contextSrv: {
     hasPermission: () => true,
     hasRole: (role: string) => true,
@@ -72,9 +73,16 @@ jest.mock('app/core/core', () => ({
       isSignedIn: true,
       uid: 'u000000001',
     },
+    isEditor: true,
   },
 }));
 
+const mockContextSrv = jest.mocked(contextSrv);
+
+beforeEach(() => {
+  mockContextSrv.isEditor = true;
+});
+
 jest.mock('app/core/services/PreferencesService', () => ({
   PreferencesService: function () {
     return {
@@ -122,17 +130,24 @@ jest.mock('./utils/useDatasource', () => ({
 
 jest.mock('./QueryLibraryDrawer', () => ({
   ...jest.requireActual('./QueryLibraryDrawer'),
-  QueryLibraryDrawer: ({ isOpen, close }: any) => {
-    const { onSave } = useQueryLibraryContext();
+  QueryLibraryDrawer: ({ close }: any) => {
+    const { onSave, isDrawerOpen, closeDrawer } = useQueryLibraryContext();
 
-    if (!isOpen) {
+    if (!isDrawerOpen) {
       return null;
     }
     return (
       <Drawer onClose={close} title="Saved queries">
         <input id="title" aria-label="title" />
-        <button onClick={onSave}>Save</button>
-        <button onClick={close}>Close</button>
+        <button
+          onClick={() => {
+            onSave?.();
+            closeDrawer();
+          }}
+        >
+          Save
+        </button>
+        <button onClick={() => closeDrawer()}>Close</button>
       </Drawer>
     );
   },
@@ -208,4 +223,14 @@ describe('QueryLibrary', () => {
     await submitAddToQueryLibrary({ title: 'Test' });
     await assertAddToQueryLibraryButtonExists(false);
   });
+
+  // change this to validate the save query is hidden when users doesn't have permissions to save a query
+  it('Does not show the saved queries button when the user doesnt have permissions to save a query', async () => {
+    mockContextSrv.isEditor = false;
+    setupQueryLibrary();
+    await waitForExplore();
+    await openQueryHistory();
+    await assertQueryHistory(['{"expr":"TEST"}']);
+    await assertAddToQueryLibraryButtonExists(false);
+  });
 });
