@@ -16,14 +16,15 @@ import {
   dateTime,
   TimeRange,
   LoadingState,
+  store,
 } from '@grafana/data';
+import { Trans, t } from '@grafana/i18n';
 import { config, reportInteraction } from '@grafana/runtime';
 import { DataQuery, TimeZone } from '@grafana/schema';
 import { Button, Modal, useTheme2 } from '@grafana/ui';
-import store from 'app/core/store';
 import { SETTINGS_KEYS } from 'app/features/explore/Logs/utils/logs';
 import { splitOpen } from 'app/features/explore/state/main';
-import { useDispatch } from 'app/types';
+import { useDispatch } from 'app/types/store';
 
 import { dataFrameToLogsModel } from '../../logsModel';
 import { sortLogRows } from '../../utils';
@@ -39,9 +40,6 @@ const getStyles = (theme: GrafanaTheme2) => {
       [theme.breakpoints.down('md')]: {
         width: '100%',
       },
-      top: '50%',
-      left: '50%',
-      transform: 'translate(-50%, -50%)',
     }),
     sticky: css({
       position: 'sticky',
@@ -491,11 +489,12 @@ export const LogRowContextModal: React.FunctionComponent<LogRowContextModalProps
 
   const loadingStateAbove = context.above.loadingState;
   const loadingStateBelow = context.below.loadingState;
+  const timeRange = getFullTimeRange();
 
   return (
     <Modal
       isOpen={open}
-      title="Log context"
+      title={t('logs.log-row-context-modal.title-log-context', 'Log context')}
       contentClassName={styles.flexColumn}
       className={styles.modal}
       onDismiss={onClose}
@@ -522,8 +521,18 @@ export const LogRowContextModal: React.FunctionComponent<LogRowContextModalProps
                     <LoadingIndicator adjective="newer" />
                   </div>
                 )}
-                {loadingStateAbove === LoadingState.Error && <div>Error loading log more logs.</div>}
-                {loadingStateAbove === LoadingState.Done && <div>No more logs available.</div>}
+                {loadingStateAbove === LoadingState.Error && (
+                  <div>
+                    <Trans i18nKey="logs.log-row-context-modal.error-loading-log-more-logs">
+                      Error loading more logs.
+                    </Trans>
+                  </div>
+                )}
+                {loadingStateAbove === LoadingState.Done && (
+                  <div>
+                    <Trans i18nKey="logs.log-row-context-modal.no-more-logs-available">No more logs available.</Trans>
+                  </div>
+                )}
               </td>
             </tr>
             <tr>
@@ -541,6 +550,7 @@ export const LogRowContextModal: React.FunctionComponent<LogRowContextModalProps
                   onClickShowField={showField}
                   onClickHideField={hideField}
                   scrollElement={null}
+                  timeRange={timeRange}
                 />
               </td>
             </tr>
@@ -564,6 +574,7 @@ export const LogRowContextModal: React.FunctionComponent<LogRowContextModalProps
                   pinnedLogs={sticky ? [row.uid] : undefined}
                   overflowingContent={true}
                   scrollElement={null}
+                  timeRange={timeRange}
                 />
               </td>
             </tr>
@@ -583,6 +594,7 @@ export const LogRowContextModal: React.FunctionComponent<LogRowContextModalProps
                     onClickShowField={showField}
                     onClickHideField={hideField}
                     scrollElement={null}
+                    timeRange={timeRange}
                   />
                 </>
               </td>
@@ -594,8 +606,18 @@ export const LogRowContextModal: React.FunctionComponent<LogRowContextModalProps
                     <LoadingIndicator adjective="older" />
                   </div>
                 )}
-                {loadingStateBelow === LoadingState.Error && <div>Error loading log more logs.</div>}
-                {loadingStateBelow === LoadingState.Done && <div>No more logs available.</div>}
+                {loadingStateBelow === LoadingState.Error && (
+                  <div>
+                    <Trans i18nKey="logs.log-row-context-modal.error-loading-log-more-logs">
+                      Error loading more logs.
+                    </Trans>
+                  </div>
+                )}
+                {loadingStateBelow === LoadingState.Done && (
+                  <div>
+                    <Trans i18nKey="logs.log-row-context-modal.no-more-logs-available">No more logs available.</Trans>
+                  </div>
+                )}
               </td>
             </tr>
           </tbody>
@@ -616,7 +638,7 @@ export const LogRowContextModal: React.FunctionComponent<LogRowContextModalProps
               dispatch(
                 splitOpen({
                   queries: [contextQuery],
-                  range: getFullTimeRange(),
+                  range: timeRange,
                   datasourceUid: contextQuery.datasource!.uid!,
                   panelsState: {
                     logs: {
@@ -632,7 +654,7 @@ export const LogRowContextModal: React.FunctionComponent<LogRowContextModalProps
               });
             }}
           >
-            Open in split view
+            <Trans i18nKey="logs.log-row-context-modal.open-in-split-view">Open in split view</Trans>
           </Button>
         )}
       </Modal.ButtonRow>
